test: Rename ReportLogData to ReportLog

BUG=chromium:1063474
TEST=./generate.sh

Change-Id: Ia8912733511344bdc538b6aac121130f529e4641
Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/infra/proto/+/2110593
Reviewed-by: Alex Zamorzaev <zamorzaev@chromium.org>
Commit-Queue: Prathmesh Prabhu <pprabhu@chromium.org>
Tested-by: Prathmesh Prabhu <pprabhu@chromium.org>
diff --git a/go/test/rtd/v1/progress.pb.go b/go/test/rtd/v1/progress.pb.go
index 8520762..708dae2 100644
--- a/go/test/rtd/v1/progress.pb.go
+++ b/go/test/rtd/v1/progress.pb.go
@@ -502,46 +502,45 @@
 func init() { proto.RegisterFile("test/rtd/v1/progress.proto", fileDescriptor_53459f08935e9319) }
 
 var fileDescriptor_53459f08935e9319 = []byte{
-	// 612 bytes of a gzipped FileDescriptorProto
-	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x94, 0xd1, 0x6e, 0xda, 0x4a,
-	0x10, 0x86, 0x8f, 0x21, 0x38, 0x30, 0x90, 0xc8, 0xd9, 0xe4, 0x9c, 0x43, 0x51, 0x5a, 0x51, 0x5f,
-	0x21, 0x55, 0xb2, 0x05, 0xed, 0x45, 0xab, 0x4a, 0xad, 0x88, 0xbd, 0xa9, 0xac, 0x52, 0x82, 0x76,
-	0x1d, 0xaa, 0xf4, 0x06, 0x39, 0xb0, 0x71, 0xac, 0x82, 0x97, 0xee, 0x2e, 0x48, 0x7d, 0x82, 0x3e,
-	0x51, 0xdf, 0xa3, 0x8f, 0x54, 0x79, 0x6d, 0x12, 0x9a, 0x26, 0xb9, 0x1b, 0xcf, 0x7c, 0xff, 0xec,
-	0x8c, 0x67, 0x76, 0xa1, 0xa5, 0x98, 0x54, 0xae, 0x50, 0x33, 0x77, 0xdd, 0x75, 0x97, 0x82, 0xc7,
-	0x82, 0x49, 0xe9, 0x2c, 0x05, 0x57, 0x1c, 0xd5, 0xb3, 0x98, 0x23, 0xd4, 0xcc, 0x59, 0x77, 0x5b,
-	0xc7, 0x31, 0xe7, 0xf1, 0x9c, 0xb9, 0x3a, 0x74, 0xb9, 0xba, 0x72, 0xa5, 0x12, 0xab, 0xa9, 0xca,
-	0x51, 0xdb, 0x81, 0xe6, 0xa8, 0x10, 0xd3, 0x24, 0xfd, 0xea, 0xcd, 0x13, 0x96, 0x2a, 0x8f, 0xa7,
-	0x57, 0x49, 0x8c, 0x10, 0xec, 0x2c, 0xb9, 0x50, 0x4d, 0xa3, 0x6d, 0x74, 0x2a, 0x44, 0xdb, 0xf6,
-	0x18, 0x0e, 0x09, 0xcb, 0x2c, 0xc2, 0xe4, 0x6a, 0xae, 0x08, 0xfb, 0xb6, 0x62, 0x52, 0x65, 0x68,
-	0x1a, 0x2d, 0x98, 0x46, 0x6b, 0x44, 0xdb, 0xe8, 0x05, 0x98, 0x42, 0x43, 0xcd, 0x52, 0xdb, 0xe8,
-	0xd4, 0x7b, 0x87, 0xce, 0x56, 0x59, 0x4e, 0xa1, 0x2f, 0x10, 0xfb, 0xc7, 0x0e, 0x98, 0xb9, 0x0b,
-	0xb9, 0x50, 0x91, 0x2a, 0x52, 0x79, 0xb2, 0xfd, 0xde, 0x93, 0x7b, 0x64, 0x0e, 0xcd, 0x00, 0x92,
-	0x73, 0xa8, 0x0b, 0x26, 0x13, 0x82, 0x0b, 0xd9, 0x2c, 0xb5, 0xcb, 0x9d, 0xfa, 0xfd, 0x0a, 0x9c,
-	0x11, 0xa4, 0x00, 0x5b, 0xbf, 0x4a, 0x50, 0xd1, 0x1e, 0xf4, 0x1a, 0x4c, 0xc9, 0x57, 0x62, 0xba,
-	0x39, 0xae, 0xfd, 0xa0, 0xd8, 0xa1, 0x9a, 0x23, 0x05, 0x8f, 0xde, 0x41, 0x55, 0xb2, 0x35, 0x13,
-	0x89, 0xfa, 0xae, 0x3b, 0xdc, 0xef, 0xd9, 0x8f, 0x68, 0x0b, 0x92, 0xdc, 0x68, 0x50, 0x17, 0x76,
-	0x67, 0x4c, 0x45, 0xc9, 0x5c, 0x36, 0xcb, 0xfa, 0x07, 0xfd, 0xef, 0xe4, 0xa3, 0x72, 0x36, 0xa3,
-	0x72, 0xa8, 0x1e, 0x15, 0xd9, 0x70, 0xf6, 0x05, 0x98, 0x79, 0x11, 0xe8, 0x3f, 0x40, 0xf4, 0xec,
-	0x9c, 0x78, 0x78, 0x72, 0x3e, 0xa4, 0x23, 0xec, 0x05, 0xa7, 0x01, 0xf6, 0xad, 0x7f, 0x50, 0x15,
-	0x76, 0x42, 0x4c, 0x43, 0xcb, 0xc8, 0x08, 0x82, 0x3f, 0x9d, 0x85, 0x78, 0x92, 0x39, 0x26, 0x3e,
-	0x09, 0xc6, 0x98, 0x58, 0x25, 0xf4, 0x2f, 0x1c, 0x68, 0xc7, 0xa0, 0x7f, 0x32, 0xa1, 0x98, 0x8c,
-	0x03, 0x0f, 0x53, 0xab, 0x6c, 0xbf, 0x87, 0xea, 0xa6, 0x46, 0xd4, 0x84, 0x23, 0x8a, 0xc7, 0x98,
-	0x04, 0xe1, 0xc5, 0x9d, 0xf4, 0x0d, 0xa8, 0x7a, 0x24, 0x08, 0x03, 0xaf, 0x3f, 0xb0, 0x0c, 0x54,
-	0x87, 0xdd, 0xcf, 0x7d, 0x32, 0x0c, 0x86, 0x1f, 0xac, 0x92, 0x7d, 0x0a, 0x15, 0x3d, 0x95, 0xec,
-	0x00, 0x1a, 0xf6, 0xc3, 0xbb, 0x95, 0xed, 0x41, 0x8d, 0x9e, 0x7b, 0x1e, 0xc6, 0x3e, 0xf6, 0x2d,
-	0x03, 0x01, 0x98, 0xa7, 0xfd, 0x60, 0x80, 0x7d, 0xab, 0x94, 0xe5, 0xa1, 0x1f, 0x83, 0xd1, 0x08,
-	0xfb, 0x56, 0xd9, 0x7e, 0x05, 0x47, 0x7f, 0x6e, 0x98, 0x5c, 0xf2, 0x54, 0x32, 0x74, 0x0c, 0x35,
-	0xc5, 0xc4, 0x22, 0x49, 0x37, 0xab, 0x51, 0x25, 0xb7, 0x0e, 0x7b, 0x08, 0x56, 0xae, 0x1a, 0xf0,
-	0xf8, 0xb1, 0xa5, 0xcc, 0x76, 0x3a, 0x52, 0xd7, 0x7a, 0x60, 0x35, 0xa2, 0xed, 0xcc, 0x37, 0x8b,
-	0x54, 0xa4, 0xa7, 0xd0, 0x20, 0xda, 0xb6, 0x0f, 0xe1, 0x60, 0x2b, 0x5f, 0x5e, 0x42, 0xef, 0xa7,
-	0x01, 0x8d, 0xed, 0xdb, 0x82, 0x28, 0x34, 0xb6, 0x6b, 0x45, 0x77, 0x97, 0xe7, 0xaf, 0x8b, 0xd2,
-	0x7a, 0xfe, 0x08, 0x51, 0x34, 0x3a, 0x82, 0xbd, 0x9b, 0xa3, 0xfd, 0x48, 0x45, 0xe8, 0xe9, 0x3d,
-	0x9a, 0xdb, 0x36, 0x5b, 0xcf, 0x1e, 0x0a, 0xe7, 0xf9, 0x3a, 0xc6, 0xc9, 0xdb, 0x2f, 0x6f, 0x62,
-	0xee, 0x4c, 0xaf, 0x05, 0x5f, 0x24, 0xab, 0x85, 0xc3, 0x45, 0xec, 0x6e, 0x3e, 0xb8, 0x74, 0x93,
-	0xf4, 0x4a, 0x44, 0xf9, 0xf3, 0xe0, 0xc6, 0xdc, 0xd5, 0xef, 0x4a, 0x92, 0xae, 0xf9, 0x34, 0x52,
-	0x09, 0x4f, 0x2f, 0x4d, 0x1d, 0x79, 0xf9, 0x3b, 0x00, 0x00, 0xff, 0xff, 0x1b, 0x7f, 0x68, 0x35,
-	0x71, 0x04, 0x00, 0x00,
+	// 608 bytes of a gzipped FileDescriptorProto
+	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x94, 0x61, 0x6f, 0xda, 0x3c,
+	0x10, 0xc7, 0x9f, 0x40, 0xa1, 0x70, 0xf0, 0x54, 0xa9, 0xdb, 0x6d, 0x0c, 0x75, 0x13, 0xcb, 0x2b,
+	0xa4, 0x49, 0x8e, 0x60, 0x7b, 0xb1, 0x69, 0xd2, 0x26, 0x1a, 0xdc, 0x29, 0x1a, 0xa3, 0xc8, 0x4e,
+	0x99, 0xba, 0x37, 0x28, 0x05, 0x37, 0x8d, 0x06, 0x31, 0xb3, 0x0d, 0xd2, 0x3e, 0xc1, 0x3e, 0xcf,
+	0xbe, 0xc9, 0x3e, 0xd2, 0x14, 0x27, 0xb4, 0xac, 0x6b, 0xfb, 0xee, 0x72, 0xf7, 0xfb, 0x9f, 0xef,
+	0x72, 0x67, 0x43, 0x53, 0x73, 0xa5, 0x5d, 0xa9, 0x67, 0xee, 0xba, 0xe3, 0x2e, 0xa5, 0x88, 0x24,
+	0x57, 0x0a, 0x2f, 0xa5, 0xd0, 0x02, 0xd5, 0xd2, 0x18, 0x96, 0x7a, 0x86, 0xd7, 0x9d, 0xe6, 0x51,
+	0x24, 0x44, 0x34, 0xe7, 0xae, 0x09, 0x5d, 0xac, 0x2e, 0x5d, 0xa5, 0xe5, 0x6a, 0xaa, 0x33, 0xd4,
+	0xc1, 0xd0, 0x18, 0xe5, 0x62, 0x16, 0x27, 0xdf, 0xbc, 0x79, 0xcc, 0x13, 0xed, 0x89, 0xe4, 0x32,
+	0x8e, 0x10, 0x82, 0x9d, 0xa5, 0x90, 0xba, 0x61, 0xb5, 0xac, 0x76, 0x89, 0x1a, 0xdb, 0x19, 0xc3,
+	0x01, 0xe5, 0xa9, 0x45, 0xb9, 0x5a, 0xcd, 0x35, 0xe5, 0xdf, 0x57, 0x5c, 0xe9, 0x14, 0x4d, 0xc2,
+	0x05, 0x37, 0x68, 0x95, 0x1a, 0x1b, 0xbd, 0x84, 0xb2, 0x34, 0x50, 0xa3, 0xd0, 0xb2, 0xda, 0xb5,
+	0xee, 0x01, 0xde, 0x2a, 0x0b, 0xe7, 0xfa, 0x1c, 0x71, 0x7e, 0xee, 0x40, 0x39, 0x73, 0x21, 0x17,
+	0x4a, 0x4a, 0x87, 0x3a, 0x4b, 0xb6, 0xd7, 0x7d, 0x7a, 0x87, 0x0c, 0xb3, 0x14, 0xa0, 0x19, 0x87,
+	0x3a, 0x50, 0xe6, 0x52, 0x0a, 0xa9, 0x1a, 0x85, 0x56, 0xb1, 0x5d, 0xbb, 0x5b, 0x41, 0x52, 0x82,
+	0xe6, 0x60, 0xf3, 0x77, 0x01, 0x4a, 0xc6, 0x83, 0xde, 0x40, 0x59, 0x89, 0x95, 0x9c, 0x6e, 0x8e,
+	0x6b, 0xdd, 0x2b, 0xc6, 0xcc, 0x70, 0x34, 0xe7, 0xd1, 0x7b, 0xa8, 0x28, 0xbe, 0xe6, 0x32, 0xd6,
+	0x3f, 0x4c, 0x87, 0x7b, 0x5d, 0xe7, 0x01, 0x6d, 0x4e, 0xd2, 0x6b, 0x0d, 0xea, 0xc0, 0xee, 0x8c,
+	0xeb, 0x30, 0x9e, 0xab, 0x46, 0xd1, 0xfc, 0xa0, 0x27, 0x38, 0x1b, 0x15, 0xde, 0x8c, 0x0a, 0x33,
+	0x33, 0x2a, 0xba, 0xe1, 0x9c, 0x73, 0x28, 0x67, 0x45, 0xa0, 0xc7, 0x80, 0xd8, 0xe9, 0x19, 0xf5,
+	0xc8, 0xe4, 0x6c, 0xc8, 0x46, 0xc4, 0xf3, 0x4f, 0x7c, 0xd2, 0xb7, 0xff, 0x43, 0x15, 0xd8, 0x09,
+	0x08, 0x0b, 0x6c, 0x2b, 0x25, 0x28, 0xf9, 0x7c, 0x1a, 0x90, 0x49, 0xea, 0x98, 0xf4, 0xa9, 0x3f,
+	0x26, 0xd4, 0x2e, 0xa0, 0x47, 0xb0, 0x6f, 0x1c, 0x83, 0xde, 0xf1, 0x84, 0x11, 0x3a, 0xf6, 0x3d,
+	0xc2, 0xec, 0xa2, 0xf3, 0x01, 0x2a, 0x9b, 0x1a, 0x51, 0x03, 0x0e, 0x19, 0x19, 0x13, 0xea, 0x07,
+	0xe7, 0xb7, 0xd2, 0xd7, 0xa1, 0xe2, 0x51, 0x3f, 0xf0, 0xbd, 0xde, 0xc0, 0xb6, 0x50, 0x0d, 0x76,
+	0xbf, 0xf4, 0xe8, 0xd0, 0x1f, 0x7e, 0xb4, 0x0b, 0xce, 0x09, 0x94, 0xcc, 0x54, 0xd2, 0x03, 0x58,
+	0xd0, 0x0b, 0x6e, 0x57, 0xf6, 0x3f, 0x54, 0xd9, 0x99, 0xe7, 0x11, 0xd2, 0x27, 0x7d, 0xdb, 0x42,
+	0x00, 0xe5, 0x93, 0x9e, 0x3f, 0x20, 0x7d, 0xbb, 0x90, 0xe6, 0x61, 0x9f, 0xfc, 0xd1, 0x88, 0xf4,
+	0xed, 0xa2, 0xf3, 0x1a, 0x0e, 0xff, 0xde, 0x30, 0xb5, 0x14, 0x89, 0xe2, 0xe8, 0x08, 0xaa, 0x9a,
+	0xcb, 0x45, 0x9c, 0x6c, 0x56, 0xa3, 0x42, 0x6f, 0x1c, 0xce, 0x10, 0xec, 0x4c, 0x35, 0x10, 0xd1,
+	0x43, 0x4b, 0x99, 0xee, 0x74, 0xa8, 0xaf, 0xcc, 0xc0, 0xaa, 0xd4, 0xd8, 0xa9, 0x6f, 0x16, 0xea,
+	0xd0, 0x4c, 0xa1, 0x4e, 0x8d, 0xed, 0x1c, 0xc0, 0xfe, 0x56, 0xbe, 0xac, 0x84, 0xee, 0x2f, 0x0b,
+	0xea, 0xdb, 0xb7, 0x05, 0x31, 0xa8, 0x6f, 0xd7, 0x8a, 0x6e, 0x2f, 0xcf, 0x3f, 0x17, 0xa5, 0xf9,
+	0xe2, 0x01, 0x22, 0x6f, 0x74, 0x00, 0xd5, 0xeb, 0xa3, 0xd1, 0xb3, 0x3b, 0xf8, 0x9b, 0x16, 0x9b,
+	0xcf, 0xef, 0x0b, 0x67, 0xb9, 0xda, 0xd6, 0xf1, 0xbb, 0xaf, 0x6f, 0x23, 0x81, 0xa7, 0x57, 0x52,
+	0x2c, 0xe2, 0xd5, 0x02, 0x0b, 0x19, 0xb9, 0x9b, 0x0f, 0xa1, 0xdc, 0x38, 0xb9, 0x94, 0x61, 0xf6,
+	0x34, 0xb8, 0x91, 0x70, 0xcd, 0x9b, 0x12, 0x27, 0x6b, 0x31, 0x0d, 0x75, 0x2c, 0x92, 0x8b, 0xb2,
+	0x89, 0xbc, 0xfa, 0x13, 0x00, 0x00, 0xff, 0xff, 0x44, 0x4e, 0x6d, 0x70, 0x6d, 0x04, 0x00, 0x00,
 }
 
 // Reference imports to suppress errors if they are not otherwise used.
@@ -561,12 +560,11 @@
 	ReportResult(ctx context.Context, in *ReportResultRequest, opts ...grpc.CallOption) (*ReportResultResponse, error)
 	// A log stream from the Remote Test Driver invocation.
 	//
-	// Each call to this method must report data for a single invocation
-	// request and log file. Data for the same file may be split over multiple
-	// ReportLogData calls. In case of concurrent methods calls for the same
-	// log file, Remote Test Servers need not make any guarantees about the
-	// interleaving of received data.
-	ReportLogData(ctx context.Context, opts ...grpc.CallOption) (ProgressSink_ReportLogDataClient, error)
+	// Each call to this method must stream logs for a single invocation request
+	// and log file. Data for the same file may be split over multiple ReportLog
+	// calls. Data received from concurrent methods calls for the same log file
+	// may be interleved arbitrarily.
+	ReportLog(ctx context.Context, opts ...grpc.CallOption) (ProgressSink_ReportLogClient, error)
 }
 
 type progressSinkClient struct {
@@ -586,30 +584,30 @@
 	return out, nil
 }
 
-func (c *progressSinkClient) ReportLogData(ctx context.Context, opts ...grpc.CallOption) (ProgressSink_ReportLogDataClient, error) {
-	stream, err := c.cc.NewStream(ctx, &_ProgressSink_serviceDesc.Streams[0], "/test.rtd.v1.ProgressSink/ReportLogData", opts...)
+func (c *progressSinkClient) ReportLog(ctx context.Context, opts ...grpc.CallOption) (ProgressSink_ReportLogClient, error) {
+	stream, err := c.cc.NewStream(ctx, &_ProgressSink_serviceDesc.Streams[0], "/test.rtd.v1.ProgressSink/ReportLog", opts...)
 	if err != nil {
 		return nil, err
 	}
-	x := &progressSinkReportLogDataClient{stream}
+	x := &progressSinkReportLogClient{stream}
 	return x, nil
 }
 
-type ProgressSink_ReportLogDataClient interface {
+type ProgressSink_ReportLogClient interface {
 	Send(*ReportLogRequest) error
 	CloseAndRecv() (*ReportLogResponse, error)
 	grpc.ClientStream
 }
 
-type progressSinkReportLogDataClient struct {
+type progressSinkReportLogClient struct {
 	grpc.ClientStream
 }
 
-func (x *progressSinkReportLogDataClient) Send(m *ReportLogRequest) error {
+func (x *progressSinkReportLogClient) Send(m *ReportLogRequest) error {
 	return x.ClientStream.SendMsg(m)
 }
 
-func (x *progressSinkReportLogDataClient) CloseAndRecv() (*ReportLogResponse, error) {
+func (x *progressSinkReportLogClient) CloseAndRecv() (*ReportLogResponse, error) {
 	if err := x.ClientStream.CloseSend(); err != nil {
 		return nil, err
 	}
@@ -627,12 +625,11 @@
 	ReportResult(context.Context, *ReportResultRequest) (*ReportResultResponse, error)
 	// A log stream from the Remote Test Driver invocation.
 	//
-	// Each call to this method must report data for a single invocation
-	// request and log file. Data for the same file may be split over multiple
-	// ReportLogData calls. In case of concurrent methods calls for the same
-	// log file, Remote Test Servers need not make any guarantees about the
-	// interleaving of received data.
-	ReportLogData(ProgressSink_ReportLogDataServer) error
+	// Each call to this method must stream logs for a single invocation request
+	// and log file. Data for the same file may be split over multiple ReportLog
+	// calls. Data received from concurrent methods calls for the same log file
+	// may be interleved arbitrarily.
+	ReportLog(ProgressSink_ReportLogServer) error
 }
 
 // UnimplementedProgressSinkServer can be embedded to have forward compatible implementations.
@@ -642,8 +639,8 @@
 func (*UnimplementedProgressSinkServer) ReportResult(ctx context.Context, req *ReportResultRequest) (*ReportResultResponse, error) {
 	return nil, status.Errorf(codes.Unimplemented, "method ReportResult not implemented")
 }
-func (*UnimplementedProgressSinkServer) ReportLogData(srv ProgressSink_ReportLogDataServer) error {
-	return status.Errorf(codes.Unimplemented, "method ReportLogData not implemented")
+func (*UnimplementedProgressSinkServer) ReportLog(srv ProgressSink_ReportLogServer) error {
+	return status.Errorf(codes.Unimplemented, "method ReportLog not implemented")
 }
 
 func RegisterProgressSinkServer(s *grpc.Server, srv ProgressSinkServer) {
@@ -668,25 +665,25 @@
 	return interceptor(ctx, in, info, handler)
 }
 
-func _ProgressSink_ReportLogData_Handler(srv interface{}, stream grpc.ServerStream) error {
-	return srv.(ProgressSinkServer).ReportLogData(&progressSinkReportLogDataServer{stream})
+func _ProgressSink_ReportLog_Handler(srv interface{}, stream grpc.ServerStream) error {
+	return srv.(ProgressSinkServer).ReportLog(&progressSinkReportLogServer{stream})
 }
 
-type ProgressSink_ReportLogDataServer interface {
+type ProgressSink_ReportLogServer interface {
 	SendAndClose(*ReportLogResponse) error
 	Recv() (*ReportLogRequest, error)
 	grpc.ServerStream
 }
 
-type progressSinkReportLogDataServer struct {
+type progressSinkReportLogServer struct {
 	grpc.ServerStream
 }
 
-func (x *progressSinkReportLogDataServer) SendAndClose(m *ReportLogResponse) error {
+func (x *progressSinkReportLogServer) SendAndClose(m *ReportLogResponse) error {
 	return x.ServerStream.SendMsg(m)
 }
 
-func (x *progressSinkReportLogDataServer) Recv() (*ReportLogRequest, error) {
+func (x *progressSinkReportLogServer) Recv() (*ReportLogRequest, error) {
 	m := new(ReportLogRequest)
 	if err := x.ServerStream.RecvMsg(m); err != nil {
 		return nil, err
@@ -705,8 +702,8 @@
 	},
 	Streams: []grpc.StreamDesc{
 		{
-			StreamName:    "ReportLogData",
-			Handler:       _ProgressSink_ReportLogData_Handler,
+			StreamName:    "ReportLog",
+			Handler:       _ProgressSink_ReportLog_Handler,
 			ClientStreams: true,
 		},
 	},
diff --git a/src/test/rtd/v1/progress.proto b/src/test/rtd/v1/progress.proto
index 3762363..2e5173b 100644
--- a/src/test/rtd/v1/progress.proto
+++ b/src/test/rtd/v1/progress.proto
@@ -37,13 +37,11 @@
 
   // A log stream from the Remote Test Driver invocation.
   //
-  // Each call to this method must report data for a single invocation
-  // request and log file. Data for the same file may be split over multiple
-  // ReportLogData calls. In case of concurrent methods calls for the same
-  // log file, Remote Test Servers need not make any guarantees about the
-  // interleaving of received data.
-  rpc ReportLogData(stream ReportLogRequest)
-    returns (ReportLogResponse);
+  // Each call to this method must stream logs for a single invocation request
+  // and log file. Data for the same file may be split over multiple ReportLog
+  // calls. Data received from concurrent methods calls for the same log file
+  // may be interleved arbitrarily.
+  rpc ReportLog(stream ReportLogRequest) returns (ReportLogResponse);
 }
 
 message ReportResultRequest {